==> estateplat-common-1.2.4-20201113.091216-505-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGzwBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttGzw;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttGzwBdc extends KttGzw {
    private String dfztdm;
    private String dfztmc;
    private String dfmjdwdm;
    private String dfmjdwmc;
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlAttribute(
            name = "DFZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
    @XmlAttribute(
            name = "DFMJDWDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfmjdwdm() {
        return dfmjdwdm;
    }

    public void setDfmjdwdm(String dfmjdwdm) {
        this.dfmjdwdm = dfmjdwdm;
    }
    @XmlAttribute(
            name = "DFMJDWMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfmjdwmc() {
        return dfmjdwmc;
    }

    public void setDfmjdwmc(String dfmjdwmc) {
        this.dfmjdwmc = dfmjdwmc;
    }
}

==> estateplat-common-1.2.4-20201116.061044-508-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGzwBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttGzw;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttGzwBdc extends KttGzw {
    private String dfztdm;
    private String dfztmc;
    private String dfmjdwdm;
    private String dfmjdwmc;
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlAttribute(
            name = "DFZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
    @XmlAttribute(
            name = "DFMJDWDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfmjdwdm() {
        return dfmjdwdm;
    }

    public void setDfmjdwdm(String dfmjdwdm) {
        this.dfmjdwdm = dfmjdwdm;
    }
    @XmlAttribute(
            name = "DFMJDWMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfmjdwmc() {
        return dfmjdwmc;
    }

    public void setDfmjdwmc(String dfmjdwmc) {
        this.dfmjdwmc = dfmjdwmc;
    }
}
